<?php

defined( 'ABSPATH' ) || exit;

use WCYandexTaxiDeliveryPlugin\Constants;
use WCYandexTaxiDeliveryPlugin\Wrappers\OrderWrapper;
use WCYandexTaxiDeliveryPlugin\View\View;
use WCYandexTaxiDeliveryPlugin\Entities\Warehouse;
use WCYandexTaxiDeliveryPlugin\Helpers\AdminUrlHelper;
use WCYandexTaxiDeliveryPlugin\Helpers\CountryRelatedDataHelper;

/** @var string $geocodeToken */
/** @var Warehouse $warehouse */
/** @var array $warehousesList */
/** @var string $warehouseCommentPlaceholder */
/** @var OrderWrapper[] $orders */
/** @var boolean $isCountryCurrency */
/** @var boolean $ordersHaveAllowedPaymentMethods */

$version  = WC_Yandex_Taxi_Delivery_Plugin_Version::get();
$locale   = get_locale();
$settings = ygo_get_settings();

// js aanslations
echo ( new View() )->buildHtml( YGO_PLUGIN_VIEWS_DIR . '/partial/_translations.php' );

wp_enqueue_script( 'jquery' );
wp_enqueue_script( 'jquery-ui-datepicker' );

// datetime
wp_enqueue_style( 'jquery-ui-css', YGO_PLUGIN_URL . '/assets/lib/jquery-ui/jquery-ui.css', [ 'jquery' ], $version );

// phones
wp_enqueue_script( 'phone-intl-lib-js', YGO_PLUGIN_URL . '/assets/lib/intlTelInput/js/intlTelInput-jquery.min.js', [ 'jquery' ], $version );
wp_enqueue_style( 'phone-intl-lib-css', YGO_PLUGIN_URL . '/assets/lib/intlTelInput/css/intlTelInput.min.css', [], $version );

if ( $settings['geocoder'] == 'google' ) {
	// google map
	wp_enqueue_script( YGO_PLUGIN_ID . '-admin-map-js', YGO_PLUGIN_URL . '/assets/js/gmap.js', [ 'jquery' ], $version );
	wp_enqueue_script( YGO_PLUGIN_ID . '-map-js', "https://maps.googleapis.com/maps/api/js?key={$geocodeToken}", [], $version );
} else {
	// yandex map
	wp_enqueue_script( YGO_PLUGIN_ID . '-map-js', "https://api-maps.yandex.ru/2.1/?lang={$locale}&apikey={$geocodeToken}", [], $version );
	wp_enqueue_script( YGO_PLUGIN_ID . '-admin-map-js', YGO_PLUGIN_URL . '/assets/js/map.js', [ 'jquery' ], $version );
}
wp_enqueue_script( YGO_PLUGIN_ID . '-form-validation', YGO_PLUGIN_URL . '/assets/js/validation.js', [ 'jquery' ], $version );
wp_enqueue_script( YGO_PLUGIN_ID . '-create-claim-js', YGO_PLUGIN_URL . '/assets/js/create-claim.js', [ 'jquery' ], $version );
?>

<h1><?= __( 'Отправка заказов в', 'yandex-go-delivery' ) ?> <?= Constants::getToPluginName() ?></h1>

<input type="hidden" name="setting_url" value="<?= AdminUrlHelper::getSettingsUrl() ?>">

<form method='POST' id="yandex-taxi-delivery_claim_form" class="yandex-taxi-delivery_form"
      action="<?= admin_url( 'admin-post.php?action=' . YGO_PLUGIN_ID . '/confirm' ) ?>"
>

    <input id="claim-key" name="key" type="hidden">
    <input id="use-price" name="use_price" type="hidden" value="<?= $isCountryCurrency ? 1 : 0 ?>">
    <input id="orders-have-allowed-payment" name="orders_have_allowed_payment" type="hidden"
           value="<?= $ordersHaveAllowedPaymentMethods ? 1 : 0 ?>">
    <div class="yandex-taxi-delivery_settings_grid">
        <div class="yandex-taxi-delivery_form__route_point yandex-taxi-delivery_setting_form__group">

            <div class="yandex-taxi-delivery_form__route_heading">
                <h2 class="yandex-taxi-delivery_form__title"><?= __( 'Точка 1 (Склад)', 'yandex-go-delivery' ) ?></h2>
            </div>

            <div class="yandex-taxi-delivery_form__row">
				<?= ( new View() )->buildHtml( __DIR__ . '/_warehouses_list.php', [
					'warehousesList' => $warehousesList,
					'selectedId'     => $warehouse->getId(),
				] ) ?>
            </div>
            <div class="yandex-taxi-delivery_form__row">
                <div class="yandex-taxi-delivery_form__column_left">
                    <div class="yandex-taxi-delivery_map__group">
                        <div class="yandex-taxi-delivery_form__group js_yandex-taxi-delivery_param_container">
                            <label for="warehouse_address"><?= __( 'Адрес', 'yandex-go-delivery' ) ?> *</label>
                            <input class="yandex-taxi-delivery_form__group__input js_yandex-taxi-delivery_form__param js_yandex-taxi-delivery_form__param_address"
                                   id="warehouse_address"
                                   type="text"
                                   name="warehouse[address]"
                                   required
                                   value="<?= _wp_specialchars( $warehouse->getAddress() ) ?>">
                            <input type="hidden"
                                   id="warehouse_coordinate"
                                   name="warehouse[coordinate]"
                                   class="js_yandex-taxi-delivery_form__param js_yandex-taxi-delivery_form__param_coordinate">
                            <span class="error-message"></span>
                        </div>
                    </div>

                    <div class="yandex-taxi-delivery_form__group row">
                        <div class="yandex-taxi-delivery_form__group_small">

                            <label for="warehouse_flat"><?= __( 'Квартира', 'yandex-go-delivery' ) ?></label>
                            <input class="js_yandex-taxi-delivery_form__param"
                                   id="warehouse_flat"
                                   name="warehouse[flat]"
                                   type="number"
                                   value="<?= _wp_specialchars( $warehouse->getFlat() ) ?>">
                        </div>

                        <div class="yandex-taxi-delivery_form__group_small">
                            <label for="warehouse_porch"><?= __( 'Подъезд', 'yandex-go-delivery' ) ?></label>
                            <input class="js_yandex-taxi-delivery_form__param"
                                   id="warehouse_porch"
                                   name="warehouse[porch]"
                                   type="text"
                                   value="<?= _wp_specialchars( $warehouse->getPorch() ) ?>">
                        </div>

                        <div class="yandex-taxi-delivery_form__group_small">
                            <label for="warehouse_floor"><?= __( 'Этаж', 'yandex-go-delivery' ) ?></label>
                            <input class="js_yandex-taxi-delivery_form__param"
                                   id="warehouse_floor"
                                   name="warehouse[floor]"
                                   type="number"
                                   value="<?= _wp_specialchars( $warehouse->getFloor() ) ?>">
                        </div>
                    </div>

                    <div class="yandex-taxi-delivery_form__group">
                        <label for="warehouse_comment"><?= __( 'Комментарий', 'yandex-go-delivery' ) ?></label>
                        <textarea
                                class="yandex-taxi-delivery_form__group__input__textarea js_yandex-taxi-delivery_form__param"
                                id="warehouse_comment"
                                name="warehouse[comment]"><?= empty( $warehouse->getComment() ) ? $warehouseCommentPlaceholder : _wp_specialchars( $warehouse->getComment() ) ?></textarea>
                    </div>
                </div>
                <div class="yandex-taxi-delivery_form__column_right">
                    <div class="yandex-taxi-delivery_form__group row">
                        <div class="yandex-taxi-delivery_map"></div>
                        <div class="yandex-taxi-delivery_address-details"></div>
                    </div>
                </div>
            </div>

            <div class="divider"></div>

            <div class="yandex-taxi-delivery_form__row">
                <div class="yandex-taxi-delivery_form__column_left">
                    <h3 class="yandex-taxi-delivery_form__contact_heading"><?= __( 'Контакт отправителя', 'yandex-go-delivery' ) ?></h3>

                    <div class="yandex-taxi-delivery_form__group js_yandex-taxi-delivery_param_container">
                        <label for="warehouse_name"><?= __( 'Имя', 'yandex-go-delivery' ) ?> *</label>
                        <input class="yandex-taxi-delivery_form__group__input js_yandex-taxi-delivery_form__param"
                               id="warehouse_name"
                               type="text"
                               name="warehouse[name]"
                               required
                               value="<?= _wp_specialchars( $warehouse->getContactName() ) ?>">
                        <span class="error-message"></span>
                    </div>

                    <div class="yandex-taxi-delivery_form__group row">
                        <div class="yandex-taxi-delivery_form__group_small js_yandex-taxi-delivery_param_container">
                            <label for="warehouse_phone"><?= __( 'Номер телефона', 'yandex-go-delivery' ) ?> *</label>
                            <input class="yandex-taxi-delivery_form__group__input js_yandex-taxi-delivery_form__param"
                                   type="tel"
                                   id="warehouse_phone"
                                   name="warehouse[phone]"
                                   required
                                   value="<?= _wp_specialchars( $warehouse->getContactPhone() ) ?>"
                            >
                            <span class="error-message"></span>
                        </div>

                        <div class="yandex-taxi-delivery_form__group_small js_yandex-taxi-delivery_param_container">
                            <label for="warehouse_email">Email *</label>
                            <input class="yandex-taxi-delivery_form__group__input js_yandex-taxi-delivery_form__param"
                                   type="text"
                                   id="warehouse_email"
                                   name="warehouse[email]"
                                   required
                                   value="<?= _wp_specialchars( $warehouse->getContactEmail() ) ?>"
                            >
                            <span class="error-message"></span>
                        </div>
                    </div>

                    <div class="yandex-taxi-delivery_form__group checkbox">
                        <input id="due_is_on" type="checkbox" name="warehouse[due][is_on]">
                        <label for="due_is_on"><?= __( 'Забрать заказ в конкретное время', 'yandex-go-delivery' ) ?></label>
                    </div>

                    <div class="yandex-taxi-delivery_form__group">
                        <label><?= __( 'Время подачи машины на склад', 'yandex-go-delivery' ) ?></label>

                        <div class="yandex-taxi-delivery_form__datetime">

							<?php $date = current_time( 'mysql' ) ?>
                            <input type="text" class="date-picker js_yandex-taxi-delivery_form__param"
                                   name="warehouse[due][date]"
                                   disabled
                                   maxlength="10"
                                   value="<?= esc_attr( date_i18n( 'Y-m-d', strtotime( $date ) ) ); ?>"
                                   pattern="<?= esc_attr( apply_filters( 'woocommerce_date_input_html_pattern', '[0-9]{4}-(0[1-9]|1[012])-(0[1-9]|1[0-9]|2[0-9]|3[01])' ) ); ?>"/>
                            @
                            &lrm;
                            <input type="number" class="hour js_yandex-taxi-delivery_form__param"
                                   disabled
                                   placeholder="<?php esc_attr_e( 'h', 'woocommerce' ); ?>"
                                   name="warehouse[due][hour]"
                                   min="0" max="23" step="1"
                                   value="<?= esc_attr( date_i18n( 'H', strtotime( $date ) ) ); ?>"
                                   pattern="([01]?[0-9]{1}|2[0-3]{1})"/>:
                            <input type="number" class="minute js_yandex-taxi-delivery_form__param"
                                   disabled
                                   placeholder="<?php esc_attr_e( 'm', 'woocommerce' ); ?>"
                                   name="warehouse[due][minute]" min="0" max="59" step="1"
                                   value="<?= esc_attr( date_i18n( 'i', strtotime( $date ) ) ); ?>"
                                   pattern="[0-5]{1}[0-9]{1}"/>
                            <span><?php
								$zoneOffset = get_option( 'gmt_offset' );
								echo $zoneOffset > 0 ? "UTC+{$zoneOffset}" : "UTC{$zoneOffset}";
								?></span>
                        </div>
                    </div>

                    <div class="yandex-taxi-delivery_form__group checkbox">
                        <input class="js_yandex-taxi-delivery_form__param"
                               id="warehouse_sms_on"
                               type="checkbox"
                               name="warehouse[sms_on]">
                        <label for="warehouse_sms_on"><?= __( 'Включить SMS подтверждение', 'yandex-go-delivery' ) ?></label>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="yandex-taxi-delivery_form__route_point_container">
		<?php foreach ( $orders as $key => $order ) {
			echo ( new View() )->buildHtml( __DIR__ . '/_route_point.php', [
				'id'                 => $order->getId(),
				'address'            => apply_filters( 'ygo/create_claim/point/address', $order->getAddress(), $order ),
				'flat'               => apply_filters( 'ygo/create_claim/point/flat', $order->getFlat(), $order ),
				'fullName'           => apply_filters( 'ygo/create_claim/point/full_name', $order->getFullName(), $order ),
				'phone'              => apply_filters( 'ygo/create_claim/point/phone', $order->getPhone(), $order ),
				'email'              => apply_filters( 'ygo/create_claim/point/email', $order->getEmail(), $order ),
				'editUrl'            => $order->getEditUrl(),
				'isFake'             => false,
				'commentPlaceHolder' => apply_filters( 'ygo/create_claim/point/comment', $order->getCommentPlaceHolder(), $order ),
				'pointNumber'        => $key + 2,
			] );
		}
		?>
    </div>

    <div class="yandex-taxi-delivery_settings_grid">
        <div class="yandex-taxi-delivery_form__container_actions yandex-taxi-delivery_setting_form__group">
            <h3><?= __( 'Новая точка в маршруте', 'yandex-go-delivery' ) ?></h3>
            <div class="yandex-taxi-delivery_form__group row start">
                <label for="add_order_id"><?= __( 'Добавить заказ №', 'yandex-go-delivery' ) ?></label>
                <input id="add_order_id" type="number" name="add_order_id">
            </div>
            <div class="yandex-taxi-delivery_form__group row start">
                <a class="button" id="yandex-taxi-add-point"><?= __( 'Добавить заказ', 'yandex-go-delivery' ) ?></a>
                <a class="button"
                   id="yandex-taxi-add-fake-point"><?= __( 'Добавить без заказа', 'yandex-go-delivery' ) ?></a>
            </div>
        </div>
    </div>

    <div id="tariffs_container">
        <div class="yandex-taxi-delivery_settings_grid">
            <div class="yandex-taxi-delivery_form__container_actions yandex-taxi-delivery_setting_form__group">
                <div class="yandex-taxi-delivery_form__group tariff-container">
                    <label class="tariff"><?= __( 'Тариф', 'yandex-go-delivery' ) ?></label>

                </div>
            </div>
        </div>
    </div>

    <div class="yandex-taxi-delivery_form__cost_sum">
        <span id='calculation-message'></span>
    </div>

    <button class="button" id="yandex-taxi-delivery-calculate"><?= __( 'Рассчитать', 'yandex-go-delivery' ) ?></button>
    <button class="button button-primary" id="yandex-taxi-delivery-confirm-button" style="display: none" type="submit">
		<?= __( 'Подтвердить заявку', 'yandex-go-delivery' ) ?>
    </button>
</form>

<?= ( new View() )->buildHtml( YGO_PLUGIN_VIEWS_DIR . '/partial/_support_contact.php' ) ?>

<script type="text/javascript">
    const intlTelInputUtilsScriptUrl = "<?= YGO_PLUGIN_URL . '/assets/lib/intlTelInput/js/utils.js' ?>";
    const intlTelInputUtilsCountry = "<?= CountryRelatedDataHelper::getPhoneCountry() ?>";

    jQuery(document).ready(function ($) {
        $('input[name*="warehouse[due][date]"], .datepicker').datepicker({
            dateFormat: "yy-mm-dd",
            minDate: 0,
        });

        $('input[type="tel"]').intlTelInput({
            initialCountry: intlTelInputUtilsCountry,
            formatOnDisplay: false,
            utilsScript: intlTelInputUtilsScriptUrl
        });

        let message = '';

        if ($('#use-price').val() == 0) {
            message = "<?= sprintf( __( 'Мы доставляем товары со стоимостью в валюте %1$s. Поменяйте валюту ваших заказов или стоимость товаров не будет учтена при доставке.\n', 'yandex-go-delivery' ), CountryRelatedDataHelper::getCurrency() )  ?>";
        }

        if (message !== '') {
            message += " <?= __( 'Вы уверены, что хотите продолжить?', 'yandex-go-delivery' ) ?>";
            if (!confirm(message)) {
                window.location.href = "<?= AdminUrlHelper::getOrdersPageUrl() ?>"
            }
        }
    });
</script>

