<?php

defined( 'ABSPATH' ) || exit;

use WCYandexTaxiDeliveryPlugin\Constants;
use WCYandexTaxiDeliveryPlugin\View\View;
use WCYandexTaxiDeliveryPlugin\Helpers\CountryRelatedDataHelper;

/** @var array $settings */
/** @var array $config */
/** @var string|null $message */

function get_custom_attribute_html( $data ) {
	$custom_attributes = array();

	if ( ! empty( $data['custom_attributes'] ) && is_array( $data['custom_attributes'] ) ) {
		foreach ( $data['custom_attributes'] as $attribute => $attribute_value ) {
			$custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $attribute_value ) . '"';
		}
	}

	return implode( ' ', $custom_attributes );
}

$version = WC_Yandex_Taxi_Delivery_Plugin_Version::get();
wp_enqueue_script( YGO_PLUGIN_ID . '-settings-js', YGO_PLUGIN_URL . '/assets/js/settings.js', [], $version );

$groups = [
	[
		'country',
	],
	[
		'token',
	],
	[
		'geocoder',
		'geocode_token',
	],
	[
		'inn',
		'vat',
	],
	[
		'enabled',
		'post_payment',
		'payment_methods',
		'payment_method_label',
		'auto_change_status',
		'assembly_delay_minutes',
	],
	[
		'discount_is_on',
		'discount_size',
		'discount_from_price',
	],
	[
		'use_order_price_for_free',
		'order_price_for_free',
	],
	[
		'fixed_price_is_on',
		'fixed_price',
	],
	[
		'price_markup',
	],
	[
		'default_weight',
		'default_width',
		'default_length',
		'default_height',
	],
];

?>
<?php echo ( new View() )->buildHtml( __DIR__ . '/../tabs.php', WC_Yandex_Taxi_Delivery_Base_Controller::admin_tabs( YGO_PLUGIN_ID . '_settings' ) ); ?>
<h2><?= __( 'Настройки плагина', 'yandex-go-delivery' ) ?></h2>

<?php if ( ! empty( $message ) ): ?><?= $message ?><?php endif ?>

<form method="POST" class="yandex-taxi-delivery_setting_form">
    <div class="yandex-taxi-delivery_settings_grid">
	    <?php foreach ( $groups as $group ): ?>
        <div class="yandex-taxi-delivery_setting_form__group">
			<?php foreach ( $group as $key ): $param = $config[ $key ]; ?>
				<?php if ( isset( $param['display'] ) && $param['display'] === false ) {
					continue;
				} ?>
                <div class="yandex-taxi-delivery_setting_form__param">
                    <label class="<?= ( $param['type'] == 'checkbox' ) ? 'checkbox-label' : '' ?>"
                           for="<?= $key ?>"><?= $param['title'] ?></label>

					<?php if ( in_array( $param['type'], [ 'text', 'number' ] ) ): ?>
                        <input id="<?= $key ?>" name="<?= $key ?>" type="<?= $param['type'] ?>"
                               value="<?= isset( $settings[ $key ] ) ? $settings[ $key ] : '' ?>"
							<?= ( isset( $param['disabled'] ) && $param['disabled'] === true ) ? 'disabled' : '' ?>
							<?= get_custom_attribute_html( $param ) ?>>

						<?php if ( $key == 'token' ): ?>
                            <a data-source='<?= json_encode( CountryRelatedDataHelper::getCabinetUrlSource() ) ?>'
                               class="button country-related-link" target="_blank">
								<?= __( 'Получить токен', 'yandex-go-delivery' ) ?>
                            </a>
                            <a data-source='<?= json_encode( CountryRelatedDataHelper::getConnectUrlSource() ) ?>'
                               class="button country-related-link" target="_blank">
								<?= __( 'Подключить Доставку Яндекс Go', 'yandex-go-delivery' ) ?>
                            </a>
						<?php endif ?>

						<?php if ( $key == 'geocode_token' ): ?>
							<?php $geocoder = $settings['geocoder'] ?? 'yandex'; ?>
							<?php if ( $geocoder == 'dadata' ) {
								$dadata_description_hidden = false;
							} else {
								$dadata_description_hidden = true;
							}
							?>
                            <div class="description dadata-description"
                                 style="display: <?= $dadata_description_hidden ? 'none' : 'inherit'; ?>;">
                                <span><?= __( 'Формат: API_key::Secret_Key', 'yandex-go-delivery' ); ?></span></div>
                            <a data-source='<?= json_encode( CountryRelatedDataHelper::getGeocoderInstructionUrlSource( $geocoder ) ) ?>'
                               class="button country-related-link" target="_blank">
								<?= __( 'Как получить токен', 'yandex-go-delivery' ) ?>
                            </a>
                            <div class="description">
                                <a data-source='<?= json_encode( CountryRelatedDataHelper::getGeocoderCabinetUrlSource( $geocoder ) ) ?>'
                                   class="button country-related-link" target="_blank">
									<?= __( 'Перейти в личный кабинет Геосервиса', 'yandex-go-delivery' ) ?></a>
                            </div>
						<?php endif ?>
					<?php endif ?>

					<?php if ( $param['type'] == 'decimal' ): ?>
                        <input class="wc_input_decimal input-text regular-input"
                               id="<?= $key ?>" name="<?= $key ?>" type="text"
                               value="<?= isset( $settings[ $key ] ) ? esc_attr( wc_format_localized_decimal( $settings[ $key ] ) ) : '' ?>"
							<?= ( isset( $param['disabled'] ) && $param['disabled'] === true ) ? 'disabled' : '' ?>
							<?= get_custom_attribute_html( $param ) ?>>
					<?php endif ?>

					<?php if ( $param['type'] == 'checkbox' ): ?>
                        <input id="<?= $key ?>" name="<?= $key ?>" type="<?= $param['type'] ?>"
                               value="1"
							<?= ( isset( $settings[ $key ] ) && $settings[ $key ] == 'yes' ) ? 'checked' : '' ?>
							<?= ( isset( $param['disabled'] ) && $param['disabled'] === true ) ? 'disabled' : '' ?>
							<?= get_custom_attribute_html( $param ) ?>>
					<?php endif ?>

					<?php if ( $param['type'] == 'select' ): ?>
                        <select id="<?= $key ?>" name="<?= $key ?>"
							<?= ( isset( $param['disabled'] ) && $param['disabled'] === true ) ? 'disabled' : '' ?>>
							<?php foreach ( $param['options'] as $optionKey => $optionLabel ): ?>
                                <option
                                        value="<?= $optionKey ?>" <?= ( isset( $settings[ $key ] ) && $settings[ $key ] == $optionKey ) ? 'selected' : '' ?>>
									<?= $optionLabel ?>
                                </option>
							<?php endforeach ?>
                        </select>
					<?php endif ?>

					<?php if ( $param['type'] == 'multiselect' ): ?>
                        <select multiple id="<?= $key ?>" name="<?= $key ?>[]"
							<?= ( isset( $param['disabled'] ) && $param['disabled'] === true ) ? 'disabled' : '' ?>>
							<?php foreach ( $param['options'] as $option ): ?>
                                <option
                                        value="<?= $option['value'] ?>" <?= isset( $settings[ $key ] ) && in_array( $option['value'], $settings[ $key ] ) ? 'selected' : '' ?>
									<?= ( isset( $option['disabled'] ) && $option['disabled'] === true ) ? 'disabled' : '' ?>>
									<?= $option['title'] ?>
                                </option>
							<?php endforeach ?>
                        </select>
					<?php endif ?>

					<?php if ( isset( $param['description'] ) ): ?>
                        <div class="description"><span><?= $param['description'] ?></span></div>
					<?php endif ?>
                </div>
			<?php endforeach ?>
        </div>
	<?php endforeach ?>
    </div>
    <button class="button button-primary"
            type="submit"><?= __( 'Сохранить настройки', 'yandex-go-delivery' ) ?></button>
</form>

<?= ( new View() )->buildHtml( YGO_PLUGIN_VIEWS_DIR . '/partial/_support_contact.php' ) ?>
