<?php

defined( 'ABSPATH' ) || exit;

use WCYandexTaxiDeliveryPlugin\Entities\Warehouse;
use WCYandexTaxiDeliveryPlugin\Constants;
use WCYandexTaxiDeliveryPlugin\Helpers\AdminUrlHelper;
use WCYandexTaxiDeliveryPlugin\View\View;

/** @var Warehouse[] $warehouses */
/** @var int|null $defaultWarehouseId */

// js translations
echo ( new View() )->buildHtml( YGO_PLUGIN_VIEWS_DIR . '/partial/_translations.php' );

$version = WC_Yandex_Taxi_Delivery_Plugin_Version::get();
wp_enqueue_script( YGO_PLUGIN_ID . '-warehouses-js', YGO_PLUGIN_URL . '/assets/js/warehouses.js', [], $version );
?>
<div class="ygo_menu_tabs">
	<?php echo ( new View() )->buildHtml( __DIR__ . '/../tabs.php', WC_Yandex_Taxi_Delivery_Base_Controller::admin_tabs( YGO_PLUGIN_ID . '_warehouses' ) ); ?>
</div>
<h2><?= __( 'Управление складами', 'yandex-go-delivery' ) ?></h2>

<div class="ygo_delivery_warehouses_table">
    <table class="widefat striped yandex-taxi-delivery_warehouse-list">
        <thead>
        <tr>
            <th>ID</th>
            <th class="ygo_delivery_warehouses_item_mobile"><?= __( 'Адрес', 'yandex-go-delivery' ) ?></th>
            <th>Email</th>
            <th><?= __( 'Имя', 'yandex-go-delivery' ) ?></th>
            <th><?= __( 'Телефон', 'yandex-go-delivery' ) ?></th>
            <th><?= __( 'По умолчанию', 'yandex-go-delivery' ) ?></th>
        </tr>
        </thead>

		<?php if ( empty( $warehouses ) ): ?>
            <tr>
                <span><?= __( 'Пока нет ни одного склада', 'yandex-go-delivery' ) ?></span>
            </tr>
		<?php endif ?>

		<?php foreach ( $warehouses as $warehouse ): ?>
            <tr>
                <td><?= $warehouse->getId() ?></td>
                <td class="ygo_delivery_warehouses_item_mobile">
                    <a href="<?= AdminUrlHelper::getWarehouseEditUrl( $warehouse->getId() ) ?>" class="ygo_delivery_warehouses_item_address"><?= $warehouse->getAddress() ?></a>
                    <div class="ygo_delivery_warehouses_item_actions">
                        <a class=""
                           href="<?= AdminUrlHelper::getWarehouseEditUrl( $warehouse->getId() ) ?>"><?= __( 'Редактировать', 'yandex-go-delivery' ) ?></a>
                        |
                        <a href="#" class="delete yandex-taxi-delivery__warehouse_delete_js"
                           data-warehouse-id="<?= $warehouse->getId() ?>"><?= __( 'Удалить', 'yandex-go-delivery' ) ?></a>
                    </div>
                </td>
                <td><?= $warehouse->getContactEmail() ?></td>
                <td><?= $warehouse->getContactName() ?></td>
                <td><?= $warehouse->getContactPhone() ?></td>
                <td><?= ( $warehouse->getId() === $defaultWarehouseId ) ? __( 'Да', 'yandex-go-delivery' ) : __( 'Нет', 'yandex-go-delivery' ) ?></td>
            </tr>
		<?php endforeach ?>
    </table>
</div>
<div>
    <a class="button"
       href="<?= AdminUrlHelper::getWarehouseEditUrl( null ) ?>"><?= __( 'Создать склад', 'yandex-go-delivery' ) ?></a>
</div>

<?= ( new View() )->buildHtml( YGO_PLUGIN_VIEWS_DIR . '/partial/_support_contact.php' ) ?>
