<?php

namespace WCYandexTaxiDeliveryPlugin\Helpers;

use WCYandexTaxiDeliveryPlugin\Constants;

/**
 * Class CountryRelatedDataHelper
 *
 * @package WCYandexTaxiDeliveryPlugin\Helpers
 */
class CountryRelatedDataHelper {
	private const RUSSIA = 'Russia';
	private const ISRAEL = 'Israel';
	private const BELARUS = 'Belarus';
	private const KAZAKHSTAN = 'Kazakhstan';

	public static function getGeocoderInstructionUrlSource( $geocoder ): array {
		$return = [
			self::ISRAEL => 'https://developers.google.com/maps/documentation/geocoding/get-api-key',
			'default'    => 'https://docs.google.com/document/d/1Y-XYaqWnST0EFTDhGr65Edt5621prU7ATojmt3o-x1M',
		];

		return $return;
	}

	public static function getGeocoderCabinetUrlSource( $geocoder ): array {
		switch ( $geocoder ) {
			case 'google':
				$return = [
					'default' => 'https://cloud.google.com/maps-platform/',
				];
				break;
			case 'dadata':
				$return = [
					'default' => 'https://dadata.ru/profile/',
				];
				break;
			case 'yandex':
			default:
				$return = [
					self::ISRAEL     => 'https://developer.tech.yandex.com/services/',
					self::BELARUS    => 'https://developer.tech.yandex.by/services/',
					self::KAZAKHSTAN => 'https://developer.tech.yandex.kz/services/',
					'default'        => 'https://developer.tech.yandex.ru/services/',
				];
				break;
		}

		return $return;
	}

	public static function getCabinetUrlSource(): array {
		return [
			self::ISRAEL     => 'https://business.yango.yandex.com/profile/settings/',
			self::BELARUS    => 'https://business.taxi.yandex.by/profile/settings/',
			self::KAZAKHSTAN => 'https://business.taxi.yandex.kz/profile/settings/',
			'default'        => 'https://business.taxi.yandex.ru/profile/settings/',
		];
	}

	public static function getConnectUrlSource(): array {
		return [
			self::ISRAEL     => 'https://yango.yandex.com/action/israel/delivery/delivery_he/?ya_medium=module&ya_campaign=woocommerce&utm_source=woocommerce&utm_medium=backend',
			self::BELARUS    => 'https://delivery.yandex.com/by-ru?ya_medium=module&ya_campaign=WooCommerce#form',
			self::KAZAKHSTAN => 'https://delivery.yandex.com/kz-ru?ya_medium=module&ya_campaign=WooCommerce#form',
			'default'        => 'https://logistics.yandex.com/business/self-registration?ya_source=businessdelivery&ya_medium=module&ya_campaign=WooCommerce#form',
		];
	}

	public static function getUpperPhoneCountry(): string {
		$country = self::getCountry();

		switch ( $country ) {
			case self::ISRAEL:
				return 'IL';
			case self::BELARUS:
				return 'BLR';
			case self::KAZAKHSTAN:
				return 'KZ';
			default:
				return 'RU';
		}
	}

	public static function getPhoneCountry(): string {
		$country = self::getCountry();

		switch ( $country ) {
			case self::ISRAEL:
				return 'il';
			case self::BELARUS:
				return 'blr';
			case self::KAZAKHSTAN:
				return 'kz';
			default:
				return 'ru';
		}
	}

	public static function getDefaultTariffsPoint(): array {
		$country = self::getCountry();

		switch ( $country ) {
			case self::ISRAEL:
				return [ 32.085443, 34.782175 ];
			case self::BELARUS:
				return [ 53.893386, 27.556720 ];
			case self::KAZAKHSTAN:
				return [ 51.120020, 71.439383 ];
			default:
				return [ 55.734148, 37.5865588 ]; // Yandex Russian Office
		}
	}

	public static function getCurrency(): string {
		$country = self::getCountry();

		switch ( $country ) {
			case self::ISRAEL:
				return 'ILS';
			case self::BELARUS:
				return 'BYN';
			case self::KAZAKHSTAN:
				return 'KZT';
			default:
				return 'RUB';
		}
	}

	public static function getCountry(): string {
		$settings = get_option( YGO_PLUGIN_SETTINGS );

		return $settings['country'] ?? self::RUSSIA;
	}
}
